cli

package
v0.1.49 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 9, 2026 License: MIT Imports: 26 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FormatTestResults added in v0.1.32

func FormatTestResults(results []script.TestResult) string

FormatTestResults formats test results for CLI output.

func NewCurlCommand

func NewCurlCommand() *cobra.Command

NewCurlCommand creates a command that parses a curl command and opens TUI.

func NewMCPCommand added in v0.1.33

func NewMCPCommand() *cobra.Command

NewMCPCommand creates the mcp subcommand for starting the MCP server.

func NewProxyCommand added in v0.1.41

func NewProxyCommand() *cobra.Command

NewProxyCommand creates the proxy command.

func NewRootCommand

func NewRootCommand(version string) *cobra.Command

NewRootCommand creates the root command.

func NewRunCommand added in v0.1.32

func NewRunCommand() *cobra.Command

NewRunCommand creates the run command.

func NewSendCommand

func NewSendCommand() *cobra.Command

NewSendCommand creates the send command.

Types

type ProxyOptions added in v0.1.41

type ProxyOptions struct {
	ListenAddr   string
	EnableHTTPS  bool
	ExportCA     string
	Verbose      bool
	BufferSize   int
	ExcludeHosts []string
	IncludeHosts []string
}

ProxyOptions holds options for the proxy command.

type RunOptions added in v0.1.32

type RunOptions struct {
	EnvFiles []string
	Verbose  bool
	JSON     bool
}

RunOptions holds options for the run command.

type SendOptions

type SendOptions struct {
	Headers            []string
	Body               string
	JSON               bool
	Timeout            time.Duration
	EnvFiles           []string
	ProxyURL           string
	CertFile           string
	KeyFile            string
	CAFile             string
	InsecureSkipVerify bool
}

SendOptions holds options for the send command.

Jump to