Documentation
¶
Index ¶
- func FormatTestResults(results []script.TestResult) string
- func NewCurlCommand() *cobra.Command
- func NewMCPCommand() *cobra.Command
- func NewProxyCommand() *cobra.Command
- func NewRootCommand(version string) *cobra.Command
- func NewRunCommand() *cobra.Command
- func NewSendCommand() *cobra.Command
- type ProxyOptions
- type RunOptions
- type SendOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FormatTestResults ¶ added in v0.1.32
func FormatTestResults(results []script.TestResult) string
FormatTestResults formats test results for CLI output.
func NewCurlCommand ¶
NewCurlCommand creates a command that parses a curl command and opens TUI.
func NewMCPCommand ¶ added in v0.1.33
NewMCPCommand creates the mcp subcommand for starting the MCP server.
func NewProxyCommand ¶ added in v0.1.41
NewProxyCommand creates the proxy command.
func NewRootCommand ¶
NewRootCommand creates the root command.
func NewRunCommand ¶ added in v0.1.32
NewRunCommand creates the run command.
Types ¶
type ProxyOptions ¶ added in v0.1.41
type ProxyOptions struct {
ListenAddr string
EnableHTTPS bool
ExportCA string
Verbose bool
BufferSize int
ExcludeHosts []string
IncludeHosts []string
}
ProxyOptions holds options for the proxy command.
type RunOptions ¶ added in v0.1.32
RunOptions holds options for the run command.
Click to show internal directories.
Click to hide internal directories.